manuel.capture — Manuel Documentation

### Navigation

- index
- Manuel Documentation »

# manuel.capture

This document explores the edge cases and boundry conditions of the manuel.capture module. It is not meant as end-user documentation, but is rather a set of tests.

## Respecting indentation

The text captured is determined by the indentation of the capture directive.

    First level of indentation.

        Second level of indentation.

            Third level of indentation.

        .. -> foo

## Nested directives

If two capture directives are nested, the outer one is effective.

    First level of indentation.

        Second level of indentation.

            Third level of indentation.

        .. -> foo

    .. -> bar

## Error reporting

If the capture directive is accidentally indented, a (reasonable) error will be generated.

    This is a block that will be captured::

        Block

        .. -> foo

### Navigation

- index
- Manuel Documentation »